@@ -12,8 +12,9 @@ km_inputs <- reactive({
   # loop needed because reactive values don't allow single bracket indexing
   km_args$data_filter <- if (input$show_filter) input$data_filter else ""
   km_args$dataset <- input$dataset
-  for (i in r_drop(names(km_args)))
+  for (i in r_drop(names(km_args))) {
     km_args[[i]] <- input[[paste0("km_", i)]]
+  }
   km_args
 })
 
@@ -29,7 +30,8 @@ output$ui_km_vars <- renderUI({
 
 output$ui_km_lambda <- renderUI({
   numericInput(
-    "km_lambda", "Lambda:", min = 0,
+    "km_lambda", "Lambda:",
+    min = 0,
     value = state_init("km_lambda", NA)
   )
 })
@@ -55,16 +57,18 @@ run_refresh(km_args, "km", init = "vars", tabs = "tabs_kclus", label = "Estimate
 output$ui_kclus <- renderUI({
   req(input$dataset)
   tagList(
-    conditionalPanel(condition = "input.tabs_kclus == 'Summary'",
+    conditionalPanel(
+      condition = "input.tabs_kclus == 'Summary'",
       wellPanel(
-        actionButton("km_run", "Estimate model", width = "100%", icon = icon("play"), class = "btn-success")
+        actionButton("km_run", "Estimate model", width = "100%", icon = icon("play", verify_fa = FALSE), class = "btn-success")
       )
     ),
     wellPanel(
       conditionalPanel(
         condition = "input.tabs_kclus == 'Summary'",
         selectInput(
-          "km_fun", label = "Algorithm:", choices = km_algorithm,
+          "km_fun",
+          label = "Algorithm:", choices = km_algorithm,
           selected = state_single("km_fun", km_algorithm, "kmeans"), multiple = FALSE
         ),
         uiOutput("ui_km_vars"),
@@ -81,11 +85,13 @@ output$ui_kclus <- renderUI({
           condition = "input.km_hc_init == true",
           wellPanel(
             selectInput(
-              "km_distance", label = "Distance measure:", choices = hc_distance,
+              "km_distance",
+              label = "Distance measure:", choices = hc_distance,
               selected = state_single("km_distance", hc_distance, "sq.euclidian"), multiple = FALSE
             ),
             selectInput(
-              "km_method", label = "Method:", choices = hc_method,
+              "km_method",
+              label = "Method:", choices = hc_method,
               selected = state_single("km_method", hc_method, "ward.D"), multiple = FALSE
             )
           )
@@ -93,27 +99,31 @@ output$ui_kclus <- renderUI({
         conditionalPanel(
           condition = "input.km_hc_init == false",
           numericInput(
-            "km_seed", "Set random seed:", min = 0,
+            "km_seed", "Set random seed:",
+            min = 0,
             value = state_init("km_seed", 1234)
           )
         ),
         numericInput(
-          "km_nr_clus", "Number of clusters:", min = 2,
+          "km_nr_clus", "Number of clusters:",
+          min = 2,
           value = state_init("km_nr_clus", 2)
         ),
         conditionalPanel(
           condition = "input.km_vars != null",
-          HTML("<label>Store cluster membership:</label>"),
+          # HTML("<label>Store cluster membership:</label>"),
+          tags$label("Store cluster membership:"),
           tags$table(
             tags$td(uiOutput("ui_km_store_name")),
-            tags$td(actionButton("km_store", "Store", icon = icon("plus")), style = "padding-top:5px;")
+            tags$td(actionButton("km_store", "Store", icon = icon("plus", verify_fa = FALSE)), class = "top_mini")
           )
         )
       ),
       conditionalPanel(
         condition = "input.tabs_kclus == 'Plot'",
         selectInput(
-          "km_plots", label = "Plot(s):", choices = km_plots,
+          "km_plots",
+          label = "Plot(s):", choices = km_plots,
           selected = state_multiple("km_plots", km_plots, "none"),
           multiple = FALSE
         )
@@ -128,16 +138,24 @@ output$ui_kclus <- renderUI({
 })
 
 km_plot <- eventReactive(c(input$km_run, input$km_plots), {
-  if (.km_available() == "available" && !is_empty(input$km_plots, "none")) {
+  if (.km_available() == "available" && !radiant.data::is_empty(input$km_plots, "none")) {
     list(plot_width = 750, plot_height = 300 * ceiling(length(input$km_vars) / 2))
   }
 })
 
-km_plot_width <- function()
-  km_plot() %>% {if (is.list(.)) .$plot_width else 650}
+km_plot_width <- function() {
+  km_plot() %>%
+    {
+      if (is.list(.)) .$plot_width else 650
+    }
+}
 
-km_plot_height <- function()
-  km_plot() %>% {if (is.list(.)) .$plot_height else 400}
+km_plot_height <- function() {
+  km_plot() %>%
+    {
+      if (is.list(.)) .$plot_height else 400
+    }
+}
 
 # output is called from the main radiant ui.R
 output$kclus <- renderUI({
@@ -190,14 +208,16 @@ output$kclus <- renderUI({
 })
 
 .summary_kclus <- reactive({
-  if (.km_available() != "available") return(.km_available())
+  if (.km_available() != "available") {
+    return(.km_available())
+  }
   summary(.kclus())
 })
 
 .plot_kclus <- eventReactive(c(input$km_run, input$km_plots), {
   if (.km_available() != "available") {
     .km_available()
-  } else if (is_empty(input$km_plots, "none")) {
+  } else if (radiant.data::is_empty(input$km_plots, "none")) {
     "Please select a plot type from the drop-down menu"
   } else {
     withProgress(message = "Generating plots", value = 1, {
@@ -206,9 +226,9 @@ output$kclus <- renderUI({
   }
 })
 
-observeEvent(input$kclus_report, {
+kclus_report <- function() {
   inp_out <- list(list(dec = 2), "")
-  if (!is_empty(input$km_plots, "none")) {
+  if (!radiant.data::is_empty(input$km_plots, "none")) {
     figs <- TRUE
     outputs <- c("summary", "plot")
     inp_out[[2]] <- list(plots = input$km_plots, custom = FALSE)
@@ -217,7 +237,7 @@ observeEvent(input$kclus_report, {
     figs <- FALSE
   }
 
-  if (!is_empty(input$km_store_name)) {
+  if (!radiant.data::is_empty(input$km_store_name)) {
     fixed <- fix_names(input$km_store_name)
     updateTextInput(session, "km_store_name", value = fixed)
     xcmd <- glue('{input$dataset} <- store({input$dataset}, result, name = "{fixed}")')
@@ -238,7 +258,7 @@ observeEvent(input$kclus_report, {
     fig.height = km_plot_height(),
     xcmd = xcmd
   )
-})
+}
 
 ## store cluster membership
 observeEvent(input$km_store, {
@@ -257,7 +277,9 @@ observeEvent(input$km_store, {
 dl_km_means <- function(path) {
   if (pressed(input$km_run)) {
     .kclus() %>%
-      {if (is.list(.)) write.csv(.$clus_means, file = path)}
+      {
+        if (is.list(.)) write.csv(.$clus_means, file = path)
+      }
   } else {
     cat("No output available. Press the Estimate button to generate the cluster solution", file = path)
   }
@@ -281,3 +303,18 @@ download_handler(
   width = km_plot_width,
   height = km_plot_height
 )
+
+observeEvent(input$kclus_report, {
+  r_info[["latest_screenshot"]] <- NULL
+  kclus_report()
+})
+
+observeEvent(input$kclus_screenshot, {
+  r_info[["latest_screenshot"]] <- NULL
+  radiant_screenshot_modal("modal_kclus_screenshot")
+})
+
+observeEvent(input$modal_kclus_screenshot, {
+  kclus_report()
+  removeModal() ## remove shiny modal after save
+})
\ No newline at end of file
